<?php

declare(strict_types=1);

namespace Drupal\page_view_counter;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;

/**
 * Provides a list controller for the page view counter entity type.
 */
final class PageViewCounterEntityListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    $header['id'] = $this->t('ID');
    $header['label'] = $this->t('PVC ID');
    $header['link'] = $this->t('URL');
    $header['views'] = $this->t('View Count');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    /** @var \Drupal\page_view_counter\PageViewCounterEntityInterface $entity */
    $row['id'] = $entity->id();
    $row['label'] = $entity->field_pvc_id->value;
    $row['link'] = new FormattableMarkup('<a href="/' . $entity->field_pvc_link->uri . '">' . $entity->label() . '</a>', []);
    $row['views'] = $entity->field_pvc_counter->value;
    return $row + parent::buildRow($entity);
  }

}
